==> vdcpy-0.0.7.tar.gz: vdcpy-0.0.7/tests/user_tests/add_user_test.py <==
import unittest

import vdcpy.user as vdc_user
import tests.utils.user_util as user_util

class AddUserTest(unittest.TestCase):

    def test_successful_add_user(self):
        user_info = {
            'name': 'unittest_user',
            'email': 'test@test.test',
            'organization': 'unittest_organization',
            'position': 'unittest_position'
        }
        new_user = vdc_user.add_user(user_info)
        self.assertEqual(type(new_user), dict)

    def test_fail_add_user_no_name(self):
        user_info = {
            'email': 'test@test.test',
            'organization': 'unittest_organization',
            'position': 'unittest_position'
        }
        try:
            new_user = vdc_user.add_user(user_info)
            self.assertEqual(new_user, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding user: 400 - {'message': 'Name is required'}"
            )
    
    def test_fail_add_user_no_email(self):
        user_info = {
            'name': 'unittest_user',
            'organization': 'unittest_organization',
            'position': 'unittest_position'
        }
        try:
            new_user = vdc_user.add_user(user_info)
            self.assertEqual(new_user, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding user: 400 - {'message': 'Email is required'}"
            )
    
    def test_fail_add_user_no_organization(self):
        user_info = {
            'name': 'unittest_user',
            'email': 'test@test.test',
            'position': 'unittest_position'
        }
        try:
            new_user = vdc_user.add_user(user_info)
            self.assertEqual(new_user, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding user: 400 - {'message': 'Organization is required'}"
            )

    def test_fail_add_user_no_position(self):
        user_info = {
            'name': 'unittest_user',
            'email': 'test@test.test',
            'organization': 'unittest_organization'
        }
        try:
            new_user = vdc_user.add_user(user_info)
            self.assertEqual(new_user, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding user: 400 - {'message': 'Position is required'}"
            )

    def tearDown(self):
        # Delete all unittest users.
        user_util.delete_unittest_users()

==> vdcpy-0.0.11.tar.gz: vdcpy-0.0.11/tests/user_tests/add_user_test.py <==
import unittest

import vdcpy.user as vdc_user
import tests.utils.user_util as user_util

class AddUserTest(unittest.TestCase):

    def test_successful_add_user(self):
        user_info = {
            'name': 'unittest_user',
            'email': 'test@test.test',
            'organization': 'unittest_organization',
            'position': 'unittest_position'
        }
        new_user = vdc_user.add_user(user_info, auth_token='t3st')
        self.assertEqual(type(new_user), dict)

    def test_fail_add_user_no_name(self):
        user_info = {
            'email': 'test@test.test',
            'organization': 'unittest_organization',
            'position': 'unittest_position'
        }
        try:
            new_user = vdc_user.add_user(user_info, auth_token='t3st')
            self.assertEqual(new_user, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding user: 400 - {'message': 'Name is required'}"
            )
    
    def test_fail_add_user_no_email(self):
        user_info = {
            'name': 'unittest_user',
            'organization': 'unittest_organization',
            'position': 'unittest_position'
        }
        try:
            new_user = vdc_user.add_user(user_info, auth_token='t3st')
            self.assertEqual(new_user, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding user: 400 - {'message': 'Email is required'}"
            )
    
    def test_fail_add_user_no_organization(self):
        user_info = {
            'name': 'unittest_user',
            'email': 'test@test.test',
            'position': 'unittest_position'
        }
        try:
            new_user = vdc_user.add_user(user_info, auth_token='t3st')
            self.assertEqual(new_user, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding user: 400 - {'message': 'Organization is required'}"
            )

    def test_fail_add_user_no_position(self):
        user_info = {
            'name': 'unittest_user',
            'email': 'test@test.test',
            'organization': 'unittest_organization'
        }
        try:
            new_user = vdc_user.add_user(user_info, auth_token='t3st')
            self.assertEqual(new_user, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding user: 400 - {'message': 'Position is required'}"
            )

    def tearDown(self):
        # Delete all unittest users.
        user_util.delete_unittest_users()
